@@ -1,8 +1,8 @@
-#' Formats swimming and diving data read with \code{read_results} into a dataframe
+#' Formats swimming and diving data read with \code{read_results} into a data
+#' frame
 #'
-#' Takes the output of \code{read_results} and cleans it, yielding a dataframe of swimming (and diving) results
-#'
-#' @author Greg Pilgrim \email{gpilgrim2670@@gmail.com}
+#' Takes the output of \code{read_results} and cleans it, yielding a data frame
+#' of swimming (and diving) results
 #'
 #' @importFrom dplyr mutate
 #' @importFrom dplyr lag
@@ -27,14 +27,39 @@
 #' @importFrom stats setNames
 #'
 #' @param file output from \code{read_results}
-#' @param avoid a list of strings.  Rows in \code{file} containing these strings will not be included. For example "Pool:", often used to label pool records, could be passed to \code{avoid}.  The default is \code{avoid_default}, which contains many strings similar to "Pool:", such as "STATE:" and "Qual:".  Users can supply their own lists to \code{avoid}.  \code{avoid} is handled before \code{typo} and \code{replacement}.
-#' @param typo a list of strings that are typos in the original results.  \code{swim_parse} is particularly sensitive to accidental double spaces, so "Central  High School", with two spaces between "Central" and "High" is a problem, which can be fixed.  Pass "Central  High School" to \code{typo}.  Unexpected commas as also an issue, for example "Texas, University of" should be fixed using \code{typo} and \code{replacement}
-#' @param replacement a list of fixes for the strings in \code{typo}.  Here one could pass "Central High School" (one space between "Central" and "High") and "Texas" to \code{replacement} fix the issues described in \code{typo}
-#' @param format_results should the results be formatted for analysis (special strings like \code{"DQ"} replaced with \code{NA}, \code{Finals_Time} as definitive column)?  Default is \code{TRUE}
-#' @param splits either \code{TRUE} or the default, \code{FALSE} - should \code{swim_parse} attempt to include splits.
-#' @param split_length either \code{25} or the default, \code{50}, the length of pool at which splits are recorded.  Not all results are internally consistent on this issue - some have races with splits by 50 and other races with splits by 25.
-#' @param relay_swimmers either \code{TRUE} or the default, \code{FALSE} - should relay swimmers be reported.  Relay swimmers are reported in separate columns named \code{Relay_Swimmer_1} etc.
-#' @return returns a data frame with columns \code{Name}, \code{Place}, \code{Age}, \code{Team}, \code{Prelims_Time}, \code{Finals_Time}, \code{Points}, \code{Event} & \code{DQ}.  Note all swims will have a \code{Finals_Time}, even if that time was actually swam in the prelims (i.e. a swimmer did not qualify for finals).  This is so that final results for an event can be generated from just one column.
+#' @param avoid a list of strings.  Rows in \code{file} containing these strings
+#'   will not be included. For example "Pool:", often used to label pool
+#'   records, could be passed to \code{avoid}.  The default is
+#'   \code{avoid_default}, which contains many strings similar to "Pool:", such
+#'   as "STATE:" and "Qual:".  Users can supply their own lists to \code{avoid}.
+#'   \code{avoid} is handled before \code{typo} and \code{replacement}.
+#' @param typo a list of strings that are typos in the original results.
+#'   \code{swim_parse} is particularly sensitive to accidental double spaces, so
+#'   "Central  High School", with two spaces between "Central" and "High" is a
+#'   problem, which can be fixed.  Pass "Central  High School" to \code{typo}.
+#'   Unexpected commas as also an issue, for example "Texas, University of"
+#'   should be fixed using \code{typo} and \code{replacement}
+#' @param replacement a list of fixes for the strings in \code{typo}.  Here one
+#'   could pass "Central High School" (one space between "Central" and "High")
+#'   and "Texas" to \code{replacement} fix the issues described in \code{typo}
+#' @param format_results should the results be formatted for analysis (special
+#'   strings like \code{"DQ"} replaced with \code{NA}, \code{Finals_Time} as
+#'   definitive column)?  Default is \code{TRUE}
+#' @param splits either \code{TRUE} or the default, \code{FALSE} - should
+#'   \code{swim_parse} attempt to include splits.
+#' @param split_length either \code{25} or the default, \code{50}, the length of
+#'   pool at which splits are recorded.  Not all results are internally
+#'   consistent on this issue - some have races with splits by 50 and other
+#'   races with splits by 25.
+#' @param relay_swimmers either \code{TRUE} or the default, \code{FALSE} -
+#'   should relay swimmers be reported.  Relay swimmers are reported in separate
+#'   columns named \code{Relay_Swimmer_1} etc.
+#' @return returns a data frame with columns \code{Name}, \code{Place},
+#'   \code{Age}, \code{Team}, \code{Prelims_Time}, \code{Finals_Time},
+#'   \code{Points}, \code{Event} & \code{DQ}.  Note all swims will have a
+#'   \code{Finals_Time}, even if that time was actually swam in the prelims
+#'   (i.e. a swimmer did not qualify for finals).  This is so that final results
+#'   for an event can be generated from just one column.
 #'
 #' @examples \dontrun{
 #' swim_parse(read_results("http://www.nyhsswim.com/Results/Boys/2008/NYS/Single.htm", node = "pre"),
@@ -48,8 +73,8 @@
 #'  splits = TRUE,
 #'  relay_swimmers = TRUE)
 #'  }
-#' @seealso \code{swim_parse} must be run on the output of \code{\link{read_results}}
-#'
+#' @seealso \code{swim_parse} must be run on the output of
+#'   \code{\link{read_results}}
 
 Swim_Parse <-
   function(file,
@@ -61,6 +86,8 @@ Swim_Parse <-
            split_length = 50,
            relay_swimmers = FALSE) {
 
+
+
     #### default typo and replacement strings ####
     typo_default <- c("typo")
 
@@ -70,19 +97,19 @@ Swim_Parse <-
       stop("typo and replacement must have the same number of elements (be the same length)")
     }
 
-    if(is.logical(format_results) == FALSE) {
+    if(any(!is.logical(format_results) & is.na(format_results)) == TRUE) {
       stop("format_results must be logical, either TRUE or FALSE")
     }
 
-    if(is.logical(splits) == FALSE) {
-      stop("plits must be logical, either TRUE or FALSE")
+    if(any(!is.logical(splits) & is.na(splits)) == TRUE) {
+      stop("splits must be logical, either TRUE or FALSE")
     }
 
     if(is.numeric(split_length) == FALSE) {
       stop("split_length must be numeric, usually 50 or 25")
     }
 
-    if(is.logical(relay_swimmers) == FALSE) {
+    if(any(!is.logical(relay_swimmers) & is.na(relay_swimmers)) == TRUE) {
       stop("relay_swimmers must be logical, either TRUE or FALSE")
     }
 
@@ -123,6 +150,9 @@ Swim_Parse <-
     # file <- read_results("https://data.ohiostatebuckeyes.com/livestats/m-swim/210302F001.htm")
     # file <- read_results(system.file("extdata", "Texas-Florida-Indiana.pdf", package = "SwimmeR"))
 
+    # file <- read_results("https://www.somersetasa.org/sasa/media/archive1/swimchamps2020/d7/1500m_mixed_090220.pdf")
+    # file <- read_results("https://www.somersetasa.org/sasa/media/archive1/swimchamps2020/d6/s11_0802.pdf")
+    # file <- read_results("https://www.somersetasa.org/sasa/media/archive1/swimchamps2020/d4/s7_0102.pdf")
     # avoid <- avoid_default
     # typo <- c("typo")
     # replacement <- c("typo")
@@ -131,38 +161,63 @@ Swim_Parse <-
     avoid <- unique(c(avoid, avoid_default))
 
     #### message only posts once per session ####
-    if(getOption("age_team_warning_0.6.0", TRUE)) {
-      message("Beginning with SwimmeR v0.6.0 the Grade and School output columns are renamed Age and Team respectively.  Please adjust your work flows as needed.")
+    ## removed in v0.11.0 7/14/21 ##
+    # if(getOption("age_team_warning_0.6.0", TRUE)) {
+    #   message("Beginning with SwimmeR v0.6.0 the Grade and School output columns are renamed Age and Team respectively.  Please adjust your work flows as needed.")
+    #
+    #   options("age_team_warning_0.6.0" = FALSE)
+    # }
 
-      options("age_team_warning_0.6.0" = FALSE)
+    if(stringr::str_detect(file[1], "^read_results_flag$") == TRUE){
+
+      # remove read_results flag
+
+      file <- file[-1]
+
+    } else{
+
+      # if read_results flag isn't present post an error
+
+      stop("Please run read_results on file prior to running swim_parse.")
     }
 
-  if (stringr::str_detect(file[1], "^A107") == TRUE) { # for .hy3 files
-    # file <- add_row_numbers(text = file)
-    data <- hy3_parse(file = file)
-    return(data)
+    if (stringr::str_detect(file[1], "^A107") == TRUE) { # for .hy3 files
+      # file <- add_row_numbers(text = file)
+      data <- hy3_parse(file = file)
+      return(data)
 
-  } else if (any(stringr::str_detect(file[1:5], "S\\.A\\.M\\.M\\.S\\.|MEET SANCTION NUMBER")) == TRUE) { # for S.A.M.M.S files
-    data <- samms_parse(file_samms = file,
-                        avoid_samms = avoid,
-                        typo_samms = typo,
-                        replacement_samms = replacement,
-                        format_samms = format_results)
-    return(data)
+    } else if (any(stringr::str_detect(file[1:6], "S\\.A\\.M\\.M\\.S\\.|MEET SANCTION NUMBER")) == TRUE) { # for S.A.M.M.S files
+      data <- samms_parse(file_samms = file,
+                          avoid_samms = avoid,
+                          typo_samms = typo,
+                          replacement_samms = replacement,
+                          format_samms = format_results)
+      return(data)
 
-  } else { # hytek files
+    } else if (any(stringr::str_detect(file, "Official Timekeeping by Omega")) == TRUE) {
 
-    #### assign row numbers ####
-    as_lines_list_2 <- file %>%
-      .[purrr::map_lgl(., stringr::str_detect, "Early take-off", negate = TRUE)] %>% # removes DQ rational used in some relay DQs that messes up line spacing between relay and swimmers/splits - must happen before adding in row numbers
-      add_row_numbers() %>%
-      .[purrr::map_lgl(., ~ !any(stringr::str_detect(., avoid)))] %>%
-      stringr::str_replace_all(stats::setNames(replacement, typo)) %>% # replace typos with replacements
-      stringr::str_replace_all("DISQUAL", " DQ ") %>%
-      stringr::str_replace_all("EVENT\\:", "Event")
+      data <- swim_parse_omega(
+        file_omega = file,
+        avoid_omega = avoid,
+        typo_omega = typo,
+        replacement_omega = replacement,
+        splits = splits,
+        split_length_omega = split_length
+      )
 
-    #### parsing html and pdf files ####
-    # if (stringr::str_detect(file[1], "^A107") == FALSE) {
+    } else { # hytek files
+
+      #### assign row numbers ####
+      as_lines_list_2 <- file %>%
+        .[purrr::map_lgl(., stringr::str_detect, "Early take-off", negate = TRUE)] %>% # removes DQ rational used in some relay DQs that messes up line spacing between relay and swimmers/splits - must happen before adding in row numbers
+        add_row_numbers() %>%
+        .[purrr::map_lgl(., ~ !any(stringr::str_detect(., avoid)))] %>%
+        stringr::str_replace_all(stats::setNames(replacement, typo)) %>% # replace typos with replacements
+        stringr::str_replace_all("DISQUAL", " DQ ") %>%
+        stringr::str_replace_all("EVENT\\:", "Event")
+
+      #### parsing html and pdf files ####
+      # if (stringr::str_detect(file[1], "^A107") == FALSE) {
 
       #### Pulls out event labels from text ####
       events <- event_parse(as_lines_list_2)
@@ -176,6 +231,7 @@ Swim_Parse <-
       Age_String <- "^SR$|^JR$|^SO$|^FR$|^[:digit:]{1,3}$|^\\d{1,3}\\-\\d{2}$"
       Para_String <- "^SB?M?\\d{1,2}$"
       Reaction_String <- "^\\+\\s?\\d\\.\\d{3}$|^\\-\\s?\\d\\.\\d{3}$|^0.00$"
+      Brit_ID_String <- "\\d{6,7}"
       # Colon_String <- "\\:\\d\\d"
 
       #### clean input data ####
@@ -185,7 +241,7 @@ Swim_Parse <-
         # .[purrr::map(., length) > 0] %>%
         .[purrr::map(., stringr::str_length) > 50] %>% # slight speed boost from cutting down length of file
         .[purrr::map_lgl(., stringr::str_detect, paste0(Time_Score_String,"|DQ|SCR"))] %>% # must have \\.\\d\\d because all swimming and diving times do
-        .[purrr::map_lgl(., stringr::str_detect, "[:alpha:]")] %>%
+        .[purrr::map_lgl(., stringr::str_detect, "[:alpha:]{2,}.*[:alpha:]")] %>% # need some letters, need them to not just be a single instance of DQ etc.
         .[purrr::map_lgl(., stringr::str_detect, "r\\:\\+?\\-?\\s?\\d", negate = TRUE)] %>% # remove reaction times
         .[purrr::map_lgl(., stringr::str_detect, "^50m", negate = TRUE)] %>%  # remove British results that start with 50m for splits lines
         # .[purrr::map_lgl(., stringr::str_detect, "[:alpha:]\\:", negate = TRUE)] %>% # remove records
@@ -236,6 +292,7 @@ Swim_Parse <-
         stringr::str_replace_all("(?<=[:alpha:]),(?=[:alpha:])", ", ") %>% # split names that don't have a space between last,first
         stringr::str_replace_all("(?<=[:alpha:])\\. (?=[:digit:])", "\\.  ") %>% # split abbreviated team names like Southern Cal. and times
         stringr::str_replace_all("(?<=\\d) (?=_)", "  ") %>% # spacing between place and athletes with */_ leading name
+
         stringr::str_replace_all("(?<=\\)) (?=[:alpha:])", "  ") %>% # spacing between place) and names
         stringr::str_replace_all("\\((?=[:digit:])", "  \\(") %>% # spacing between (YoB) and name, for British results
         stringr::str_replace_all(" FR ", "       FR      ") %>% # split age and team
@@ -243,6 +300,7 @@ Swim_Parse <-
         stringr::str_replace_all(" JR ", "       JR      ") %>% # split age and team
         stringr::str_replace_all(" SR ", "       SR      ") %>% # split age and team
         stringr::str_replace_all("(SM?B?1\\d{1})(\\d{1,2})", "\\1   \\2") %>%  # split para classification and age
+        stringr::str_replace_all("(\\d{6,7})([:alpha:])", "\\1   \\2") %>%  # split Brit ID and Name
         stringr::str_replace_all(" NT ", "       NT      ") %>% # split prelim and final
         stringr::str_replace_all("(?<=[:alpha:])\\s{2,3}(?=[:alpha:])", " ") %>% # testing 12/21/2020 would help with typos
         stringr::str_replace_all("(?<=[:alpha:]) (?=\\d)", "  ") %>% # split name and age
@@ -285,21 +343,76 @@ Swim_Parse <-
         suppressWarnings(
           df_9 <- data_length_9 %>%
             list_transform() %>%
-            dplyr::mutate(Para = dplyr::case_when(stringr::str_detect(V3, Para_String) == TRUE ~ V3,
-                                                  TRUE ~ "NA"),
-                          Age = dplyr::case_when(stringr::str_detect(V3, Age_String) == TRUE ~ V3,
-                                                 stringr::str_detect(V4, Age_String) == TRUE ~ V4,
-                                                 TRUE ~ "NA")) %>%
+            dplyr::na_if("") %>%
+            dplyr::mutate(ID = dplyr::case_when(stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V2,
+                                                TRUE ~ "NA")) %>%
+            dplyr::mutate(Name = dplyr::case_when(stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V3,
+                                                  TRUE ~ V2)) %>%
+            dplyr::mutate(
+              Para = dplyr::case_when(stringr::str_detect(V3, Para_String) == TRUE ~ V3,
+                                      TRUE ~ "NA"),
+              Age = dplyr::case_when(
+                stringr::str_detect(V3, Age_String) == TRUE ~ V3,
+                stringr::str_detect(V4, Age_String) == TRUE ~ V4,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Team = dplyr::case_when(
+                stringr::str_detect(V3, Age_String) == TRUE ~ V4,
+                stringr::str_detect(V3, Para_String) == TRUE &
+                  stringr::str_detect(V4, Age_String) == TRUE ~ V5,
+                stringr::str_detect(V2, Brit_ID_String) == TRUE &
+                  stringr::str_detect(V4, Age_String) == TRUE ~ V5,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Prelims_Time = dplyr::case_when(
+                stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V4,
+                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V5,
+                stringr::str_detect(V6, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V7, Time_Score_Specials_String) == TRUE ~ V6,
+                stringr::str_detect(V7, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V8, Time_Score_Specials_String) == TRUE ~ V7,
+                TRUE ~ "NA"
+              ),
+              Finals_Time = dplyr::case_when(
+                stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V5,
+                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V6,
+                stringr::str_detect(V6, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V7, Time_Score_Specials_String) == TRUE ~ V7,
+                stringr::str_detect(V7, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V8, Time_Score_Specials_String) == TRUE ~ V8,
+                TRUE ~ "NA"
+              ),
+              Points = dplyr::case_when(
+                stringr::str_detect(V6, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V7, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V8, "^\\d{1,4}\\.?\\d?\\d?$") == TRUE ~ V8,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            # dplyr::mutate(Para = dplyr::case_when(stringr::str_detect(V3, Para_String) == TRUE ~ V3,
+            #                                       TRUE ~ "NA"),
+            #               Age = dplyr::case_when(stringr::str_detect(V3, Age_String) == TRUE ~ V3,
+            #                                      stringr::str_detect(V4, Age_String) == TRUE ~ V4,
+            # TRUE ~ "NA")) %>%
             dplyr::na_if("NA") %>%
             dplyr::select(
               Place = V1,
-              Name = V2,
+              ID,
+              Name,
               Para,
               Age,
-              Team = V5,
-              Prelims_Time = V6,
-              Finals_Time = V7,
-              Points = V8,
+              Team,
+              Prelims_Time,
+              Finals_Time,
+              Points,
               Row_Numb = V9
             )
         )
@@ -317,6 +430,10 @@ Swim_Parse <-
             list_transform() %>%
             filter(stringr::str_detect(V1, "\\.") == FALSE) %>% # occasionally old results with DQs in the splits will end up here - this removes them
             dplyr::na_if("") %>%
+            dplyr::mutate(ID = dplyr::case_when(stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V2,
+                                                TRUE ~ "NA")) %>%
+            dplyr::mutate(Name = dplyr::case_when(stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V3,
+                                                  TRUE ~ V2)) %>%
             dplyr::mutate(
               Para = dplyr::case_when(stringr::str_detect(V3, Para_String) == TRUE ~ V3,
                                       TRUE ~ "NA"),
@@ -331,6 +448,8 @@ Swim_Parse <-
                 stringr::str_detect(V3, Age_String) == TRUE ~ V4,
                 stringr::str_detect(V3, Para_String) == TRUE &
                   stringr::str_detect(V4, Age_String) == TRUE ~ V5,
+                stringr::str_detect(V2, Brit_ID_String) == TRUE &
+                  stringr::str_detect(V4, Age_String) == TRUE ~ V5,
                 TRUE ~ "NA"
               )
             ) %>%
@@ -363,7 +482,8 @@ Swim_Parse <-
             dplyr::na_if("NA") %>%
             dplyr::select(
               Place = V1,
-              Name = V2,
+              ID,
+              Name,
               Age,
               Para,
               Team,
@@ -384,41 +504,79 @@ Swim_Parse <-
         suppressWarnings(
           df_7 <- data_length_7 %>%
             list_transform() %>%
-            dplyr::mutate(Place = dplyr::case_when(stringr::str_detect(V1, "\\d") == TRUE ~ V1,
-                                                                 TRUE ~ "10000"),
-              Age = dplyr::case_when(stringr::str_detect(V3, Age_String) == TRUE ~ V3,
-                                                 TRUE ~ "NA"),
-                          Team = dplyr::case_when(stringr::str_detect(V3, Age_String) == TRUE ~ V4,
-                                                  stringr::str_detect(V3, Age_String) == FALSE & stringr::str_detect(V4, Time_Score_Specials_String) == TRUE ~ V3,
-                                                  TRUE ~ "NA"),
-                          Prelims_Time = dplyr::case_when(
-                            stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V4,
-                            stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V5,
-                            TRUE ~ "NA"
-                          ),
-                          Finals_Time = dplyr::case_when(
-                            stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V5,
-                            stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V6, Time_Score_Specials_String) == FALSE ~ V5,
-                            stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V6,
-                            TRUE ~ "NA"
-                          ),
-                          Points = dplyr::case_when(
-                            # stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
-                              stringr::str_detect(V5, Finals_Time) == TRUE &
-                                stringr::str_detect(V6, "^5\\d\\.|^4\\d\\.|^3\\d\\.|^2\\d\\.") == FALSE &
-                              stringr::str_detect(V6, "^\\d{1,2}\\.?\\d?\\d?") ~ V6,
-                            TRUE ~ "NA"
-                          )
+            dplyr::mutate(Place = dplyr::case_when(stringr::str_detect(V1, "^\\d{1,3}$") == TRUE ~ V1,
+                                                   stringr::str_detect(V1, Brit_ID_String) == TRUE ~ "NA",
+                                                   TRUE ~ "10000")) %>%
+            dplyr::mutate(ID = dplyr::case_when(stringr::str_detect(V1, Brit_ID_String) == TRUE ~ V1,
+                                                stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V2,
+                                                TRUE ~ "NA")) %>%
+            dplyr::mutate(
+              Name = dplyr::case_when(
+                stringr::str_detect(V1, Brit_ID_String) == TRUE &
+                  stringr::str_detect(V2, Age_String) == TRUE ~ "NA",
+                stringr::str_detect(V2, Brit_ID_String) == TRUE ~ V3,
+                TRUE ~ V2
+              )
+            ) %>%
+            dplyr::mutate(
+              Para = dplyr::case_when(stringr::str_detect(V3, Para_String) == TRUE ~ V3,
+                                      TRUE ~ "NA"),
+              Age = dplyr::case_when(
+                stringr::str_detect(V2, Age_String) == TRUE ~ V2,
+                stringr::str_detect(V3, Age_String) == TRUE ~ V3,
+                stringr::str_detect(V4, Age_String) == TRUE ~ V4,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Team = dplyr::case_when(
+                stringr::str_detect(V2, Age_String) == TRUE ~ V3,
+                stringr::str_detect(V3, Age_String) == TRUE ~ V4,
+                stringr::str_detect(V3, Age_String) == FALSE &
+                  stringr::str_detect(V4, Time_Score_Specials_String) == TRUE ~ V3,
+                stringr::str_detect(V3, Age_String) == TRUE ~ V4,
+                stringr::str_detect(V3, Para_String) == TRUE &
+                  stringr::str_detect(V4, Age_String) == TRUE ~ V5,
+                stringr::str_detect(V2, Brit_ID_String) == TRUE &
+                  stringr::str_detect(V4, Age_String) == TRUE ~ V5,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Prelims_Time = dplyr::case_when(
+                stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V4,
+                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V5,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Finals_Time = dplyr::case_when(
+                stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V5,
+                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V6, Time_Score_Specials_String) == FALSE ~ V5,
+                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE &
+                  stringr::str_detect(V6, Time_Score_Specials_String) == TRUE ~ V6,
+                TRUE ~ "NA"
+              )
+            ) %>%
+            dplyr::mutate(
+              Points = dplyr::case_when(
+                # stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
+                stringr::str_detect(V5, Finals_Time) == TRUE &
+                  stringr::str_detect(V6, "^5\\d\\.|^4\\d\\.|^3\\d\\.|^2\\d\\.") == FALSE &
+                  stringr::str_detect(V6, "^\\d{1,2}\\.?\\d?\\d?") ~ V6,
+                TRUE ~ "NA"
+              )
             ) %>%
             dplyr::na_if("NA") %>%
             dplyr::select(
               Place,
-              Name = V2,
+              ID,
+              Para,
+              Name,
               Age,
               Team,
               Prelims_Time,
@@ -464,7 +622,7 @@ Swim_Parse <-
                 stringr::str_detect(V3, Time_Score_Specials_String) == TRUE &
                   stringr::str_detect(V4, Time_Score_Specials_String) == TRUE ~ V3,
                 stringr::str_detect(V4, Time_Score_Specials_String) == TRUE &
-                stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V4,
+                  stringr::str_detect(V5, Time_Score_Specials_String) == TRUE ~ V4,
                 TRUE ~ "NA"
               ),
               Finals_Time = dplyr::case_when(
@@ -518,7 +676,7 @@ Swim_Parse <-
               ),
               Age = dplyr::case_when(stringr::str_detect(V2, Age_String) == TRUE ~ V2,
                                      stringr::str_detect(V3, Age_String) == TRUE ~ V3,
-                          TRUE ~ "NA"),
+                                     TRUE ~ "NA"),
               Para = dplyr::case_when(stringr::str_detect(V2, Para_String) == TRUE ~ V2,
                                       stringr::str_detect(V3, Para_String) == TRUE ~ V3,
                                       TRUE ~ "NA"),
@@ -538,7 +696,7 @@ Swim_Parse <-
                 stringr::str_detect(V3, Time_Score_Specials_String) == TRUE &
                   stringr::str_detect(V4, Time_Score_Specials_String) == FALSE ~ V3,
                 # stringr::str_detect(V3, Time_Score_Specials_String) == TRUE &
-                  stringr::str_detect(V4, Time_Score_Specials_String) == TRUE ~ V4,
+                stringr::str_detect(V4, Time_Score_Specials_String) == TRUE ~ V4,
                 TRUE ~ "NA"
               )
             ) %>%
@@ -715,8 +873,8 @@ Swim_Parse <-
             # Place = dplyr::na_if(Place, "NA"),
             Row_Numb = as.numeric(Row_Numb)
           )
-          # ) %>%
-          # dplyr::filter(Row_Numb >= Min_Row_Numb)
+        # ) %>%
+        # dplyr::filter(Row_Numb >= Min_Row_Numb)
       )
 
       if("Points" %in% names(data) == FALSE){
@@ -761,12 +919,10 @@ Swim_Parse <-
 
       #### adding relay swimmers in ####
       if (relay_swimmers == TRUE) {
-        # relay_swimmers_df <- collect_relay_swimmers(as_lines_list_2, typo_2 = typo, replacement_2 = replacement)
-        relay_swimmers_df <- collect_relay_swimmers_2(as_lines_list_2)
-        # relay_swimmers_df <- relay_swimmers
+        relay_swimmers_df <- collect_relay_swimmers(as_lines_list_2)
 
         relay_swimmers_df <-
-        transform(relay_swimmers_df, Row_Numb_Adjusted = data$Row_Numb[findInterval(Row_Numb, data$Row_Numb)]) %>%
+          transform(relay_swimmers_df, Row_Numb_Adjusted = data$Row_Numb[findInterval(Row_Numb, data$Row_Numb)]) %>%
           dplyr::select(-Row_Numb)
 
         data <- data %>%
@@ -785,9 +941,9 @@ Swim_Parse <-
           transform(splits_df, Row_Numb_Adjusted = data$Row_Numb[findInterval(Row_Numb, data$Row_Numb)]) %>%
           dplyr::select(-Row_Numb)
 
-          data <- data %>%
-            dplyr::left_join(splits_df, by = c("Row_Numb" = "Row_Numb_Adjusted")) %>%
-            dplyr::select(!dplyr::starts_with("Split"), stringr::str_sort(names(.), numeric = TRUE)) # keep splits columns in order
+        data <- data %>%
+          dplyr::left_join(splits_df, by = c("Row_Numb" = "Row_Numb_Adjusted")) %>%
+          dplyr::select(!dplyr::starts_with("Split"), stringr::str_sort(names(.), numeric = TRUE)) # keep splits columns in order
 
       }
 
@@ -812,7 +968,7 @@ Swim_Parse <-
 
       return(data)
 
-  }
+    }
 
   }
 
